@@ -9,7 +9,7 @@ async def make_request(url, payload, headers=None):
         async with httpx.AsyncClient(timeout=1000) as client:
             response = await client.post(url, data=safe_json_dumps(payload), headers=headers)
             response.raise_for_status()  # Raise exception for non-2xx status codes
-            return response.json()       # or just return response if you want the full object
+            return response       # or just return response if you want the full object
 
 
 def get_kwargs_bools(key,bools,**kwargs):
@@ -23,13 +23,14 @@ def get_solcatcherSettings(getApi=False,**kwargs):
     bools,kwargs = get_kwargs_bools(key='headers',bools=bools,**kwargs)
     headers = bools.get('headers',get_headers())
     bools,kwargs = get_kwargs_bools(key='solcatcherApiKey',bools=bools,**kwargs)
+    apiKey = bools.get('apiKey')
     if apiKey or getApi:
         apiKey = apiKey or getApi
         if isinstance(apiKey,bool):
             apiKey=None
         headers = get_db_header(headers=headers,api_key=apiKey)
     headers = bools.get('headers',headers) or get_headers()
-    return kwargs,solcatcherSettings,headers,bools
+    return kwargs,bools.get('solcatcherSettings'),headers,bools
 def runSolcatcherSettings(response,solcatcherSettings):
     usedKeys = []
     status_code = response.status_code
@@ -52,7 +53,7 @@ def runSolcatcherSettings(response,solcatcherSettings):
             if key == 'getStatusCode':
                 get_status_code = value
     if get_status_code:
-        return {"result" = response,"status_code":status_code}
+        return {"result":response,"status_code":status_code}
     return response
 
 async def async_call_solcatcher_ts(endpoint,*args,**kwargs):
@@ -124,18 +125,17 @@ async def async_make_rate_limited_call(method, params, url_1_only=True, url_2_on
             headers = headers,
             **kwargs
         )
-        result = runSolcatcherSettings(response,solcatcherSettings)
+
         if bools.get('getStatusCode'):
-            if isinstance(result,dict):
+            if isinstance(response,dict):
                 status_code = response.get('status_code')
                 if status_code and status_code != 429:
                     if bools.get('getResult'):
-                        result = result.get('result',response)
+                        result = response.get('result',response)
                     return result
-            if bools.get('getResult'):
-                result = result.get('result',response)
-        elif result:
-            return result
+
+        elif response:
+            return response
     # If no response after all attempts, return empty or raise an exception
     return []
 
